@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2018-2021 the orix developers
+# Copyright 2018-2022 the orix developers
 #
 # This file is part of orix.
 #
@@ -311,6 +311,7 @@ class Misorientation(Rotation):
         return_figure=False,
         wireframe_kwargs=None,
         size=None,
+        figure_kwargs=None,
         **kwargs,
     ):
         """Plot misorientations in axis-angle space or the Rodrigues
@@ -342,6 +343,9 @@ class Misorientation(Rotation):
             If not given, all misorientations are plotted. If given, a
             random sample of this `size` of the misorientations is
             plotted.
+        figure_kwargs : dict, optional
+            Dictionary of keyword arguments passed to
+            :func:`matplotlib.pyplot.figure` if `figure` is not given.
         kwargs
             Keyword arguments passed to
             :meth:`orix.plot.AxAnglePlot.scatter` or
@@ -359,7 +363,10 @@ class Misorientation(Rotation):
         from orix.plot.rotation_plot import _setup_rotation_plot
 
         figure, ax = _setup_rotation_plot(
-            figure=figure, projection=projection, position=position
+            figure=figure,
+            projection=projection,
+            position=position,
+            figure_kwargs=figure_kwargs,
         )
 
         # Plot wireframe
@@ -549,7 +556,7 @@ class Orientation(Misorientation):
         Scalar
         """
         dot_products = self.unit.dot(other.unit).data
-        angles = np.nan_to_num(np.arccos(2 * dot_products ** 2 - 1))
+        angles = np.nan_to_num(np.arccos(2 * dot_products**2 - 1))
         return Scalar(angles)
 
     def dot(self, other):
@@ -562,7 +569,7 @@ class Orientation(Misorientation):
         dot_outer
         """
         symmetry = self.symmetry.outer(other.symmetry).unique()
-        misorientation = (~self) * other
+        misorientation = other * ~self
         all_dot_products = Rotation(misorientation).dot_outer(symmetry).data
         highest_dot_product = np.max(all_dot_products, axis=-1)
         return Scalar(highest_dot_product)
@@ -577,7 +584,7 @@ class Orientation(Misorientation):
         dot
         """
         symmetry = self.symmetry.outer(other.symmetry).unique()
-        misorientation = (~self).outer(other)
+        misorientation = other.outer(~self)
         all_dot_products = Rotation(misorientation).dot_outer(symmetry).data
         highest_dot_product = np.max(all_dot_products, axis=-1)
         return Scalar(highest_dot_product)
@@ -635,7 +642,7 @@ class Orientation(Misorientation):
             n_decimals = np.finfo(dot_products.dtype).precision
             dot_products = da.round(dot_products, n_decimals)
 
-            angles_dask = da.arccos(2 * dot_products ** 2 - 1)
+            angles_dask = da.arccos(2 * dot_products**2 - 1)
             angles_dask = da.nan_to_num(angles_dask)
 
             # Create array in memory and overwrite, chunk by chunk
@@ -647,7 +654,7 @@ class Orientation(Misorientation):
                 da.store(sources=angles_dask, targets=angles)
         else:
             dot_products = ori.dot_outer(ori).data
-            angles = np.arccos(2 * dot_products ** 2 - 1)
+            angles = np.arccos(2 * dot_products**2 - 1)
             angles = np.nan_to_num(angles)
 
         return Scalar(angles)
@@ -792,6 +799,7 @@ class Orientation(Misorientation):
         wireframe_kwargs=None,
         size=None,
         direction=None,
+        figure_kwargs=None,
         **kwargs,
     ):
         """Plot orientations in axis-angle space, the Rodrigues
@@ -828,6 +836,9 @@ class Orientation(Misorientation):
             Sample direction to plot with respect to crystal directions.
             If not given, the out of plane direction, sample Z, is used.
             Only used when plotting IPF(s).
+        figure_kwargs : dict, optional
+            Dictionary of keyword arguments passed to
+            :func:`matplotlib.pyplot.figure` if `figure` is not given.
         kwargs
             Keyword arguments passed to
             :meth:`orix.plot.AxAnglePlot.scatter`,
@@ -852,6 +863,7 @@ class Orientation(Misorientation):
                 return_figure=return_figure,
                 wireframe_kwargs=wireframe_kwargs,
                 size=size,
+                figure_kwargs=figure_kwargs,
                 **kwargs,
             )
         else:
@@ -869,7 +881,10 @@ class Orientation(Misorientation):
                     hemisphere = "upper"
 
                 figure, axes = _setup_inverse_pole_figure_plot(
-                    symmetry=symmetry, direction=direction, hemisphere=hemisphere
+                    symmetry=symmetry,
+                    direction=direction,
+                    hemisphere=hemisphere,
+                    figure_kwargs=figure_kwargs,
                 )
             else:
                 axes = np.asarray(figure.axes)
@@ -905,7 +920,7 @@ class Orientation(Misorientation):
         `dp = dparr.compute()`.
         """
         symmetry = self.symmetry.outer(other.symmetry).unique()
-        misorientation = (~self)._outer_dask(other, chunk_size=chunk_size)
+        misorientation = other._outer_dask(~self, chunk_size=chunk_size)
 
         # Summation subscripts
         str1 = "abcdefghijklmnopqrstuvwxy"[: misorientation.ndim]
