@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2018-2021 the orix developers
+# Copyright 2018-2022 the orix developers
 #
 # This file is part of orix.
 #
@@ -35,12 +35,13 @@ Rotations or orientations can be inside or outside of an orientation region.
 """
 
 import itertools
+
 import numpy as np
 
 from orix.quaternion import Quaternion
 from orix.quaternion.rotation import Rotation
 from orix.quaternion.symmetry import C1, get_distinguished_points
-from orix.vector.neo_euler import Rodrigues, AxAngle
+from orix.vector import AxAngle, Rodrigues
 
 _EPSILON = 1e-9  # small number to avoid round off problems
 
@@ -199,7 +200,7 @@ class OrientationRegion(Rotation):
         d = (-self.axis).dot_outer(g.unit).data
         x = n * d
         with np.errstate(divide="ignore"):
-            omega = 2 * np.arctan(np.where(x != 0, x ** -1, np.pi))
+            omega = 2 * np.arctan(np.where(x != 0, x**-1, np.pi))
 
         # Keep the smallest allowed angle
         omega[omega < 0] = np.pi
