@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2018-2021 the orix developers
+# Copyright 2018-2022 the orix developers
 #
 # This file is part of orix.
 #
@@ -44,7 +44,7 @@ def vector(request):
     return Vector3d(request.param)
 
 
-@pytest.fixture(params=[(0.5, 0.5, 0.5, 0.5), (0.5 ** 0.5, 0, 0, 0.5 ** 0.5)])
+@pytest.fixture(params=[(0.5, 0.5, 0.5, 0.5), (0.5**0.5, 0, 0, 0.5**0.5)])
 def orientation(request):
     return Orientation(request.param)
 
@@ -368,7 +368,7 @@ class TestOrientationInitialization:
 class TestOrientation:
     @pytest.mark.parametrize("symmetry", [C1, C2, C3, C4, D2, D3, D6, T, O, Oh])
     def test_get_distance_matrix(self, symmetry):
-        q = [(0.5, 0.5, 0.5, 0.5), (0.5 ** 0.5, 0, 0, 0.5 ** 0.5)]
+        q = [(0.5, 0.5, 0.5, 0.5), (0.5**0.5, 0, 0, 0.5**0.5)]
         o = Orientation(q, symmetry=symmetry)
         o = o.map_into_symmetry_reduced_zone()
         angles_numpy = o.get_distance_matrix()
@@ -394,10 +394,9 @@ class TestOrientation:
 
     @pytest.mark.parametrize("symmetry", [C1, C2, C3, C4, D2, D3, D6, T, O, Oh])
     def test_angle_with(self, symmetry):
-        q = [(0.5, 0.5, 0.5, 0.5), (0.5 ** 0.5, 0, 0, 0.5 ** 0.5)]
+        q = [(0.5, 0.5, 0.5, 0.5), (0.5**0.5, 0, 0, 0.5**0.5)]
         r = Rotation(q)
         o = Orientation(q, symmetry=symmetry)
-        o = o.map_into_symmetry_reduced_zone()
 
         is_equal = np.allclose((~o).angle_with(o).data, (~r).angle_with(r).data)
         if symmetry.name in ["1", "m3m"]:
@@ -418,7 +417,11 @@ class TestOrientation:
             orientation = Misorientation(orientation)
             orientation.symmetry = (C2, D6)
             orientation = orientation.map_into_symmetry_reduced_zone()
-        fig_axangle = orientation.scatter(return_figure=True)
+        fig_size = (5, 5)
+        fig_axangle = orientation.scatter(
+            return_figure=True, figure_kwargs=dict(figsize=fig_size)
+        )
+        assert (fig_axangle.get_size_inches() == fig_size).all()
         assert isinstance(fig_axangle.axes[0], AxAnglePlot)
         fig_rodrigues = orientation.scatter(projection="rodrigues", return_figure=True)
         assert isinstance(fig_rodrigues.axes[0], RodriguesPlot)
@@ -457,7 +460,11 @@ class TestOrientation:
         ori = Orientation.from_euler(np.radians((325, 48, 163)), symmetry=Oh)
 
         # Returned figure has the expected default properties
-        fig = ori.scatter("ipf", return_figure=True)
+        fig_size = (5, 5)
+        fig = ori.scatter(
+            "ipf", return_figure=True, figure_kwargs=dict(figsize=fig_size)
+        )
+        assert (fig.get_size_inches() == fig_size).all()
         axes = fig.axes[0]
         assert isinstance(axes, InversePoleFigurePlot)
         assert len(fig.axes) == 1
@@ -522,3 +529,21 @@ def test_set_symmetry_deprecation_warning_misorientation():
     o = Misorientation.random((3, 2))
     with pytest.warns(np.VisibleDeprecationWarning, match="Function `set_symmetry()"):
         _ = o.set_symmetry(C2, C2)
+
+
+def test_get_identity():
+    """Get the identity orientation via two alternative routes."""
+    o1 = Orientation([0.4884, 0.1728, 0.2661, 0.8129])
+    o2 = Orientation([0.8171, -0.2734, 0.161, -0.4813])
+
+    # Route 1 from a Misorientation instance
+    m12_1 = o2 - o1
+    o3_1 = (m12_1 * o1) * ~o2
+
+    # Route 2 from a third Orientation instance
+    m12_2 = o2 * ~o1
+    o3_2 = (m12_2 * o1) * ~o2
+
+    assert np.allclose(m12_1.data, m12_2.data)
+    assert np.allclose(o3_1.data, o3_2.data)
+    assert np.allclose(o3_1.data, [1, 0, 0, 0])
