@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2018-2021 the orix developers
+# Copyright 2018-2022 the orix developers
 #
 # This file is part of orix.
 #
@@ -299,6 +299,13 @@ def test_kwargs_unique(rotation):
     rotation.unique(return_index=False, return_inverse=True)
 
 
+def test_unique_inverse():
+    r = Rotation.random((20,))
+    u, inverse = r.unique(return_inverse=True)
+    m = u[inverse] * ~r
+    assert np.allclose(m.angle.data, 0)
+
+
 @pytest.mark.parametrize(
     "rotation, improper, expected, improper_expected",
     [
@@ -442,7 +449,7 @@ def test_dot_outer_quat(rotation, improper, quaternion, expected):
     [
         ([1, 0, 0, 0], [0, 0, 1]),
         ([-1, 0, 0, 0], [0, 0, -1]),
-        ([0, 0.5 ** 0.5, 0.5 ** 0.5, 0], [0.5 ** 0.5, 0.5 ** 0.5, 0]),
+        ([0, 0.5**0.5, 0.5**0.5, 0], [0.5**0.5, 0.5**0.5, 0]),
         ([[1, 0, 0, 0], [-1, 0, 0, 0]], [[0, 0, 1], [0, 0, -1]]),
     ],
     indirect=["rotation"],
@@ -456,7 +463,7 @@ def test_axis(rotation, expected):
     "rotation, improper",
     [
         ([(1, 0, 0, 0), (1, 0, 0, 0)], [0, 1]),
-        ([(0.5 ** 0.5, 0, 0, 0.5 ** 0.5)], [1]),
+        ([(0.5**0.5, 0, 0, 0.5**0.5)], [1]),
     ],
 )
 def test_antipodal(rotation, improper):
