@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2018-2021 the orix developers
+# Copyright 2018-2022 the orix developers
 #
 # This file is part of orix.
 #
@@ -21,7 +21,7 @@ from diffpy.structure.spacegroups import GetSpaceGroup
 import numpy as np
 import pytest
 
-from orix.crystal_map.phase_list import Phase, PhaseList
+from orix.crystal_map import Phase, PhaseList
 from orix.quaternion.symmetry import Symmetry, O
 
 
