@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2018-2021 the orix developers
+# Copyright 2018-2022 the orix developers
 #
 # This file is part of orix.
 #
@@ -20,7 +20,7 @@ import numpy as np
 import pytest
 
 from orix.projections import StereographicProjection
-from orix.vector.vector3d import Vector3d
+from orix.vector import Vector3d
 
 
 @pytest.fixture
